package com.jsowell.pile.mapper;

import com.jsowell.pile.domain.PileModelInfo;
import com.jsowell.pile.vo.web.PileModelInfoVO;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 充电桩型号信息Mapper接口
 *
 * @author jsowell
 * @date 2022-08-26
 */
@Repository
public interface PileModelInfoMapper {
    /**
     * 查询充电桩型号信息
     *
     * @param id 充电桩型号信息主键
     * @return 充电桩型号信息
     */
    public PileModelInfo selectPileModelInfoById(Long id);

    /**
     * 查询充电桩型号信息列表
     *
     * @param pileModelInfo 充电桩型号信息
     * @return 充电桩型号信息集合
     */
    public List<PileModelInfo> selectPileModelInfoList(PileModelInfo pileModelInfo);

    /**
     * 新增充电桩型号信息
     *
     * @param pileModelInfo 充电桩型号信息
     * @return 结果
     */
    public int insertPileModelInfo(PileModelInfo pileModelInfo);

    /**
     * 修改充电桩型号信息
     *
     * @param pileModelInfo 充电桩型号信息
     * @return 结果
     */
    public int updatePileModelInfo(PileModelInfo pileModelInfo);

    /**
     * 删除充电桩型号信息
     *
     * @param id 充电桩型号信息主键
     * @return 结果
     */
    public int deletePileModelInfoById(Long id);

    /**
     * 批量删除充电桩型号信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deletePileModelInfoByIds(Long[] ids);

    /**
     * 通过桩编号集合获取型号表中数据
     *
     * @param pileSns 桩编号集合
     * @return PileModelInfo对象
     */
    List<PileModelInfoVO> getPileModelInfoByPileSnList(@Param("pileSnList") List<String> pileSns);
}
